aboutsummaryrefslogtreecommitdiff
path: root/run_unittests.py
diff options
context:
space:
mode:
Diffstat (limited to 'run_unittests.py')
-rwxr-xr-xrun_unittests.py8
1 files changed, 7 insertions, 1 deletions
diff --git a/run_unittests.py b/run_unittests.py
index b599a5f..0814b34 100755
--- a/run_unittests.py
+++ b/run_unittests.py
@@ -2397,9 +2397,15 @@ class WindowsTests(BasePlatformTests):
self.build()
# Immediately rebuilding should not do anything
self.assertBuildIsNoop()
# Changing mtime of sample.ico should rebuild everything
self.utime(os.path.join(testdir, 'res', 'sample.ico'))
self.assertRebuiltTarget('prog')
+ # Changing mtime of resource.h should rebuild myres.rc and then prog
+ # (resource compiler depfile generation is not yet implemented for msvc)
+ env = Environment(testdir, self.builddir, get_fake_options(self.prefix), [])
+ if env.detect_c_compiler(False).get_id() != 'msvc':
+ self.utime(os.path.join(testdir, 'inc', 'resource', 'resource.h'))
+ self.assertRebuiltTarget('prog')
class LinuxlikeTests(BasePlatformTests):
@@ -2397,9 +2397,15 @@ class WindowsTests(BasePlatformTests):
# Immediately rebuilding should not do anything
self.assertBuildIsNoop()
- # Changing mtime of sample.ico should rebuild everything
+ # Changing mtime of sample.ico should rebuild prog
self.utime(os.path.join(testdir, 'res', 'sample.ico'))
self.assertRebuiltTarget('prog')